package com.op.mes.service;

import com.op.mes.domain.ProRecipeContent;

import java.util.List;


/**
 * 配药配方内容Service接口
 *
 * @author yinjinlu
 * @date 2022-05-12
 */
public interface IProRecipeContentService
{
    /**
     * 查询配药配方内容
     *
     * @param contentId 配药配方内容主键
     * @return 配药配方内容
     */
    public ProRecipeContent selectProRecipeContentByContentId(String contentId);

    /**
     * 查询配药配方内容列表
     *
     * @param proRecipeContent 配药配方内容
     * @return 配药配方内容集合
     */
    public List<ProRecipeContent> selectProRecipeContentList(ProRecipeContent proRecipeContent);

    /**
     * 新增配药配方内容
     *
     * @param proRecipeContent 配药配方内容
     * @return 结果
     */
    public int insertProRecipeContent(ProRecipeContent proRecipeContent);

    /**
     * 修改配药配方内容
     *
     * @param proRecipeContent 配药配方内容
     * @return 结果
     */
    public int updateProRecipeContent(ProRecipeContent proRecipeContent);

    /**
     * 批量删除配药配方内容
     *
     * @param contentIds 需要删除的配药配方内容主键集合
     * @return 结果
     */
    public int deleteProRecipeContentByContentIds(String[] contentIds);

    /**
     * 删除配药配方内容信息
     *
     * @param contentId 配药配方内容主键
     * @return 结果
     */
    public int deleteProRecipeContentByContentId(String contentId);
}
